aboutsummaryrefslogtreecommitdiffstats
path: root/contrib/tools/bison/src/complain.h
diff options
context:
space:
mode:
authorAlexander Smirnov <alex@ydb.tech>2024-07-08 15:54:05 +0000
committerAlexander Smirnov <alex@ydb.tech>2024-07-08 15:54:05 +0000
commitfc7be18c76af2e700641f3598c4856baeef1428e (patch)
tree11dbca45eb321c3a4dd08b12152acc6ef5dd3fa9 /contrib/tools/bison/src/complain.h
parentec0e7ed6da6fb317741fd8468602949a1362eca5 (diff)
parentc92cb9d3a19331916f0c274d80e67f02a62caa9b (diff)
downloadydb-fc7be18c76af2e700641f3598c4856baeef1428e.tar.gz
Merge branch 'rightlib' into mergelibs-240708-1553
Diffstat (limited to 'contrib/tools/bison/src/complain.h')
-rw-r--r--contrib/tools/bison/src/complain.h28
1 files changed, 17 insertions, 11 deletions
diff --git a/contrib/tools/bison/src/complain.h b/contrib/tools/bison/src/complain.h
index 0d81503df7..266992f6f4 100644
--- a/contrib/tools/bison/src/complain.h
+++ b/contrib/tools/bison/src/complain.h
@@ -1,7 +1,7 @@
/* Declaration for error-reporting function for Bison.
- Copyright (C) 2000-2002, 2006, 2009-2013 Free Software Foundation,
- Inc.
+ Copyright (C) 2000-2002, 2006, 2009-2015, 2018-2019 Free Software
+ Foundation, Inc.
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
@@ -78,8 +78,7 @@ void complain_init (void);
typedef enum
{
- /**< Issue no warnings. */
- Wnone = 0,
+ Wnone = 0, /**< Issue no warnings. */
Wmidrule_values = 1 << warning_midrule_values,
Wyacc = 1 << warning_yacc,
@@ -120,22 +119,29 @@ void complain_indent (location const *loc, warnings flags, unsigned *indent,
__attribute__ ((__format__ (__printf__, 4, 5)));
+/** GNU Bison extension not valid with POSIX Yacc. */
+void bison_directive (location const *loc, char const *directive);
+
/** Report an obsolete syntax, suggest the updated one. */
void deprecated_directive (location const *loc,
char const *obsolete, char const *updated);
-/** Report a repeated directive for a rule. */
+/** Report a repeated directive. */
void duplicate_directive (char const *directive,
location first, location second);
-/** Warnings treated as errors shouldn't stop the execution as regular errors
- should (because due to their nature, it is safe to go on). Thus, there are
- three possible execution statuses. */
+/** Report a repeated directive for a rule. */
+void duplicate_rule_directive (char const *directive,
+ location first, location second);
+
+/** Warnings treated as errors shouldn't stop the execution as regular
+ errors should (because due to their nature, it is safe to go
+ on). Thus, there are three possible execution statuses. */
typedef enum
{
- status_none,
- status_warning_as_error,
- status_complaint
+ status_none, /**< No diagnostic issued so far. */
+ status_warning_as_error, /**< A warning was issued (but no error). */
+ status_complaint /**< An error was issued. */
} err_status;
/** Whether an error was reported. */